@@ -5,6 +5,12 @@ test_that("photor", {
   expect_equal(nrow(photor(350, lambda = seq(300, 700, 1))), 401)
 })
 
+test_that("photor", {
+  expect_equal(ncol(photor(350, beta.band=TRUE)), 2)
+  expect_equal(nrow(photor(350, lambda = seq(300, 700, 1), beta.band=TRUE)), 401)
+})
+
+
 test_that("logistic", {
   expect_equal(ncol(logistic(x0=350,L=60,k=0.08)), 2)
   expect_equal(nrow(logistic(x0=350,L=60,k=0.08)), 401)
@@ -22,7 +28,17 @@ for (i in 1:length(midpoint)) {
 }
 names(R)[2:ncol(R)]<-midpoint
 
-#1.CTTKmodel trichromatic
+#1.CTTKmodel dichromatic
+test_that("CTTKmodel", {
+  expect_equal(ncol(CTTKmodel(photo=2,
+                              R=R,
+                              I=D65,
+                              Rb=Rb,
+                              C=bee)), 6)
+})
+
+
+#1.CTTKmodeltrichromatic
 test_that("CTTKmodel", {
   expect_equal(ncol(CTTKmodel(photo=c("tri"),
                                 R=R,
@@ -56,8 +72,24 @@ test_that("CTTKmodel", {
                               C=photor(c(350,420,490,560)))), 9)
 })
 
+test_that("CTTKmodel", {
+  expect_equal(ncol(CTTKmodel(photo=6,
+                              R=R,
+                              I=D65,
+                              Rb=Rb,
+                              C=photor(c(350,380,420,490,520,560)))), 18)
+})
 
 #3. EMmodel trichromatic
+test_that("EMmodel", {
+  expect_equal(ncol(EMmodel(photo=2,
+                            R=R,
+                            I=D65,
+                            Rb=Rb,
+                            C=bee)), 6)
+})
+
+
 test_that("EMmodel", {
   expect_equal(ncol(EMmodel(photo=c("tri"),
                               R=R,
@@ -91,19 +123,29 @@ test_that("EMmodel", {
                               C=photor(c(350,420,490,560)))), 9)
 })
 
+
+test_that("EMmodel", {
+  expect_equal(ncol(EMmodel(photo=6,
+                            R=R,
+                            I=D65,
+                            Rb=Rb,
+                            C=photor(c(350,380,420,490,520,560)))), 18)
+})
+
+
 #5. RNLmodel, dichromatic, log=F, noise=T
 test_that("RNLmodel", {
   expect_equal(ncol(RNLmodel(photo=c("di"),
                             model="linear",
-                            R=R,
+                            R1=R,
                             I=D65,
                             Rb=Rb,
                             C=photor(c(420,560)),
                             noise=TRUE,
-                            e=c(0.1,0.05))), 6)
+                            e=c(0.1,0.05))), 13)
   expect_equal(nrow(RNLmodel(photo=c("di"),
                              model="linear",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(420,560)),
@@ -115,15 +157,15 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(ncol(RNLmodel(photo=c("di"),
                              model="linear",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(420,560)),
                              noise=F,
-                             v=0.1, n=c(1,2))), 6)
+                             v=0.1, n=c(1,2))), 13)
   expect_equal(nrow(RNLmodel(photo=c("di"),
                              model="linear",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(420,560)),
@@ -136,15 +178,15 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(ncol(RNLmodel(photo=c("di"),
                              model="log",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(420,560)),
                              noise=TRUE,
-                             e=c(0.1,0.05))), 6)
+                             e=c(0.1,0.05))), 13)
   expect_equal(nrow(RNLmodel(photo=c("di"),
                              model="log",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(420,560)),
@@ -156,15 +198,15 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(ncol(RNLmodel(photo=c("di"),
                              model="log",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(420,560)),
                              noise=F,
-                             v=0.1, n=c(1,2))), 6)
+                             v=0.1, n=c(1,2))), 13)
   expect_equal(nrow(RNLmodel(photo=c("di"),
                              model="log",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(420,560)),
@@ -177,15 +219,15 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(ncol(RNLmodel(photo=c("tri"),
                              model="linear",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,560)),
                              noise=TRUE,
-                             e=c(0.1,0.07,0.05))), 9)
+                             e=c(0.1,0.07,0.05))), 20)
   expect_equal(nrow(RNLmodel(photo=c("tri"),
                              model="linear",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,560)),
@@ -197,15 +239,15 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(ncol(RNLmodel(photo=c("tri"),
                              model="linear",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,560)),
                              noise=F,
-                             v=0.1, n=c(1,1.5,2))), 9)
+                             v=0.1, n=c(1,1.5,2))), 20)
   expect_equal(nrow(RNLmodel(photo=c("tri"),
                              model="linear",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,560)),
@@ -218,15 +260,15 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(ncol(RNLmodel(photo=c("tri"),
                              model="log",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,560)),
                              noise=TRUE,
-                             e=c(0.1,0.07,0.05))), 9)
+                             e=c(0.1,0.07,0.05))), 20)
   expect_equal(nrow(RNLmodel(photo=c("tri"),
                              model="log",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,560)),
@@ -238,15 +280,15 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(ncol(RNLmodel(photo=c("tri"),
                              model="log",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,560)),
                              noise=F,
-                             v=0.1, n=c(1,1.5,2))), 9)
+                             v=0.1, n=c(1,1.5,2))), 20)
   expect_equal(nrow(RNLmodel(photo=c("tri"),
                              model="log",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,560)),
@@ -259,15 +301,15 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(ncol(RNLmodel(photo=c("tetra"),
                              model="linear",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,490,560)),
                              noise=TRUE,
-                             e=c(0.1,0.07,0.05,0.04))), 12)
+                             e=c(0.1,0.07,0.05,0.04))), 27)
   expect_equal(nrow(RNLmodel(photo=c("tetra"),
                              model="linear",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,490,560)),
@@ -279,15 +321,15 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(ncol(RNLmodel(photo=c("tetra"),
                              model="linear",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,490,560)),
                              noise=F,
-                             v=0.1, n=c(1,1.5,2,2))), 12)
+                             v=0.1, n=c(1,1.5,2,2))), 27)
   expect_equal(nrow(RNLmodel(photo=c("tetra"),
                              model="linear",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,490,560)),
@@ -300,15 +342,15 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(ncol(RNLmodel(photo=c("tetra"),
                              model="log",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,490,560)),
                              noise=TRUE,
-                             e=c(0.1,0.07,0.05,0.04))), 12)
+                             e=c(0.1,0.07,0.05,0.04))), 27)
   expect_equal(nrow(RNLmodel(photo=c("tetra"),
                              model="log",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,490,560)),
@@ -320,15 +362,15 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(ncol(RNLmodel(photo=c("tetra"),
                              model="log",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,490,560)),
                              noise=F,
-                             v=0.1, n=c(1,1.5,2,2))), 12)
+                             v=0.1, n=c(1,1.5,2,2))), 27)
   expect_equal(nrow(RNLmodel(photo=c("tetra"),
                              model="log",
-                             R=R,
+                             R1=R,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,490,560)),
@@ -336,6 +378,41 @@ test_that("RNLmodel", {
                              v=0.1, n=c(1,1.5,2,2))), 9)
 })
 
+test_that("RNLmodel", {
+  expect_equal(ncol(RNLmodel(photo=5,
+                             model="log",
+                             R1=R,
+                             I=D65,
+                             Rb=Rb,
+                             C=photor(c(350,420,490,560,600)),
+                             noise=F,
+                             v=0.1, n=c(1,1.5,2,2,2))), 26)
+  expect_equal(nrow(RNLmodel(photo=5,
+                             model="log",
+                             R1=R,
+                             I=D65,
+                             Rb=Rb,
+                             C=photor(c(350,420,490,560,600)),
+                             noise=F,
+                             v=0.1, n=c(1,1.5,2,2,2))), 9)
+})
+
+
+test_that("RNLthres", {
+  expect_equal(ncol(RNLthres(photo=5,
+                             I=D65,
+                             Rb=Rb,
+                             C=photor(c(350,420,490,560,600)),
+                             noise=F,
+                             v=0.1, n=c(1,1.5,2,2,2))), 3)
+  expect_equal(nrow(RNLthres(photo=5,
+                             I=D65,
+                             Rb=Rb,
+                             C=photor(c(350,420,490,560,600)),
+                             noise=F,
+                             v=0.1, n=c(1,1.5,2,2,2))), 401)
+})
+
 
 #deltaS=0
 #deltaS=0
@@ -346,7 +423,7 @@ test_that("CTTKmodel", {
                               R=Rb,
                               I=D65,
                               Rb=Rb,
-                              C=bee)$deltaSo, 0)
+                              C=bee)$deltaS, 0)
 })
 
 #2.CTTKmodel tetrachromatic
@@ -355,7 +432,7 @@ test_that("CTTKmodel", {
                               R=Rb,
                               I=D65,
                               Rb=Rb,
-                              C=photor(c(350,420,490,560)))$deltaSo, 0)
+                              C=photor(c(350,420,490,560)))$deltaS, 0)
 })
 
 #3. EMmodel trichromatic
@@ -365,7 +442,7 @@ test_that("EMmodel", {
                             R=cbind(EMRb[,1],EMRb[,2]+10),
                             I=D65,
                             Rb=EMRb,
-                            C=bee)$deltaSo, 2), 0)
+                            C=bee)$deltaS, 2), 0)
 })
 
 
@@ -383,7 +460,7 @@ test_that("EMmodel", {
 test_that("RNLmodel", {
   expect_equal(RNLmodel(photo=c("di"),
                              model="linear",
-                             R=Rb,
+                             R1=Rb,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(420,560)),
@@ -395,7 +472,7 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(RNLmodel(photo=c("di"),
                              model="linear",
-                             R=Rb,
+                             R1=Rb,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(420,560)),
@@ -408,7 +485,7 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(RNLmodel(photo=c("di"),
                              model="log",
-                             R=Rb,
+                             R1=Rb,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(420,560)),
@@ -420,7 +497,7 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(RNLmodel(photo=c("di"),
                              model="log",
-                             R=Rb,
+                             R1=Rb,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(420,560)),
@@ -433,7 +510,7 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(RNLmodel(photo=c("tri"),
                              model="linear",
-                             R=Rb,
+                             R1=Rb,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,560)),
@@ -445,7 +522,7 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(RNLmodel(photo=c("tri"),
                              model="linear",
-                             R=Rb,
+                             R1=Rb,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,560)),
@@ -458,7 +535,7 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(RNLmodel(photo=c("tri"),
                              model="log",
-                             R=Rb,
+                             R1=Rb,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,560)),
@@ -470,7 +547,7 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(RNLmodel(photo=c("tri"),
                              model="log",
-                             R=Rb,
+                             R1=Rb,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,560)),
@@ -483,7 +560,7 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(RNLmodel(photo=c("tetra"),
                              model="linear",
-                             R=Rb,
+                             R1=Rb,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,490,560)),
@@ -495,7 +572,7 @@ test_that("RNLmodel", {
 test_that("RNLmodel", {
   expect_equal(RNLmodel(photo=c("tetra"),
                              model="linear",
-                             R=Rb,
+                             R1=Rb,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,490,560)),
@@ -508,7 +585,7 @@ test_that("RNLmodel", {
 test_that("RNLmodel, tetrachromatic, log=T, noise=T", {
   expect_equal(RNLmodel(photo=c("tetra"),
                              model="log",
-                             R=Rb,
+                             R1=Rb,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,490,560)),
@@ -520,7 +597,7 @@ test_that("RNLmodel, tetrachromatic, log=T, noise=T", {
 test_that("RNLmodel, tetrachromatic, log=F, noise=F", {
   expect_equal(RNLmodel(photo=c("tetra"),
                              model="log",
-                             R=Rb,
+                             R1=Rb,
                              I=D65,
                              Rb=Rb,
                              C=photor(c(350,420,490,560)),
@@ -558,7 +635,7 @@ test_that("CTTKmodel, tetrachromatic, AVICOL", {
 test_that("RNLmodel, dichromatic, AVICOL", {
   model<-RNLmodel(photo="di",
                 model="log",
-                R=r500,
+                R1=r500,
                 I=D65,
                 Rb=Rb,
                 C=photor(c(420,560)),
@@ -567,63 +644,49 @@ test_that("RNLmodel, dichromatic, AVICOL", {
                 n=c(1,1.77))
   expect_equal(round(model$e1, 3), 0.050)
   expect_equal(round(model$e2, 3), 0.038)
-  expect_equal(round(model$f1, 3), 0.034)
-  expect_equal(round(model$f2, 3), 0.588)
-  expect_equal(round(model$deltaSo, 3), 8.853)
+  expect_equal(round(model$E1_R1, 3), 0.034)
+  expect_equal(round(model$E2_R1, 3), 0.588)
+  expect_equal(round(model$deltaS, 3), 8.853)
 })
 
 test_that("RNLmodel, trichromatic, AVICOL", {
   model<-RNLmodel(photo="tri",
                   model="log",
-                  R=r500,
+                  R1=r500,
                   I=D65,
                   Rb=Rb,
                   C=bee,
                   noise=F,
                   v=0.05,
                   n=c(1,5,10))
-  expect_equal(round(model$f1, 3), -0.366)
-  expect_equal(round(model$f2, 3), 0.171)
-  expect_equal(round(model$f3, 3), 0.564)
+  expect_equal(round(model$E1_R1, 3), -0.366)
+  expect_equal(round(model$E2_R1, 3), 0.171)
+  expect_equal(round(model$E3_R1, 3), 0.564)
   expect_equal(round(model$e1, 3), 0.050)
   expect_equal(round(model$e2, 3), 0.022)
   expect_equal(round(model$e3, 3), 0.016)
-  expect_equal(round(model$deltaSo, 3), 21.094)
+  expect_equal(round(model$deltaS, 3), 21.094)
 })
 
 test_that("RNLmodel, tetrachromatic, AVICOL", {
     model<-RNLmodel(photo="tetra",
                    model="log",
-                   R=r500,
+                   R1=r500,
                    I=D65,
                    Rb=Rb,
                    C=photor(c(350,420,490,560)),
                    noise=F,
                    v=0.05,
                    n=c(1, 1.9, 2.2, 2.1))
-    expect_equal(round(model$f1, 3), -0.900)
-    expect_equal(round(model$f2, 3), 0.034)
-    expect_equal(round(model$f3, 3), 0.488)
-    expect_equal(round(model$f4, 3), 0.588)
+    expect_equal(round(model$E1_R1, 3), -0.900)
+    expect_equal(round(model$E2_R1, 3), 0.034)
+    expect_equal(round(model$E3_R1, 3), 0.488)
+    expect_equal(round(model$E4_R1, 3), 0.588)
     expect_equal(round(model$e1, 3), 0.050)
     expect_equal(round(model$e2, 3), 0.036)
     expect_equal(round(model$e3, 3), 0.034)
     expect_equal(round(model$e4, 3), 0.035)
-    expect_equal(round(model$deltaSo, 3), 26.530)
-})
-
-test_that("RNLmodel, trichromatic, AVICOL", {
-  model<-EMmodel(photo="tri",
-          R=r500,
-          I=D65,
-          Rb=Rb,
-          C=bee)
-  expect_equal(round(model$f1, 3), -0.843)
-  expect_equal(round(model$f2, 3), 0.394)
-  expect_equal(round(model$f3, 3), 1.298)
-  expect_equal(round(model$u, 3), -0.992)
-  expect_equal(round(model$s, 3), 0.464)
-  expect_equal(round(model$m, 3), 1.528)
+    expect_equal(round(model$deltaS, 3), 26.530)
 })
 
 
@@ -633,16 +696,12 @@ test_that("RNLmodel, tetrachromatic, vismodel and tcs", {
                  I=D65,
                  Rb=Rb,
                  C=photor(c(350,420,490,560)))
-  expect_equal(round(model$f1, 3), -2.072)
-  expect_equal(round(model$f2, 3), 0.079)
-  expect_equal(round(model$f3, 3), 1.123)
-  expect_equal(round(model$f4, 3), 1.354)
-  expect_equal(round(model$u, 3), -4.284)
-  expect_equal(round(model$s, 3), 0.163)
-  expect_equal(round(model$m, 3), 2.322)
-  expect_equal(round(model$l, 3), 2.799)
-  expect_equal(round(model$x, 3), 1.615)
-  expect_equal(round(model$y, 3), 0.595)
-  expect_equal(round(model$z, 3), -4.534)
-  expect_equal(round(model$deltaSo, 3), 4.850)
+  expect_equal(round(model$E1, 3), -4.284)
+  expect_equal(round(model$E2, 3), 0.163)
+  expect_equal(round(model$E3, 3), 2.322)
+  expect_equal(round(model$E4, 3), 2.799)
+  expect_equal(round(model$X1, 3), 1.615)
+  expect_equal(round(model$X2, 3), 0.595)
+  expect_equal(round(model$X3, 3), -4.534)
+  expect_equal(round(model$deltaS, 3), 4.850)
 })
